@@ -9,7 +9,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 import gym
 from gym import error, spaces, utils
-#from gym.utils import seeding
+from gym.utils import seeding
 #import statsmodels.api as sm
 #import statsmodels.formula.api as smf
 import pandas.util.testing as tm
@@ -124,8 +124,6 @@ class DiscreteEnv(gym.Env):
     self.horizon = 20
     return self.state
 
-  def close(self):
-        p.disconnect()
 
 
 # In[ ]:
